# HG changeset patch
# User Yuriy Izorkin <lafiel@elven.pw>
# Date 1712127735 -10800
#      Wed Apr 03 10:02:15 2024 +0300
# Node ID a354490ed342b3ae0a6abb8d70db80605294aa97
# Parent  ccd7e4022a2498a930c9e0927a9820f7ea17ae13
MIME: changed type for iso and img files to application/vnd.efi.(iso|img).

For .iso and .img files, the application/vnd.efi.(iso|img)
MIME type is used according to IANA [1].

Although these media types were registered for the purpose
of using them with EFI, they were defined broadly to
include all uncompressed disk images [2].

These types are recommended for booting a RAM disk over
HTTP [3].

Link for reference:

[1] https://www.iana.org/assignments/media-types/application/vnd.efi.iso
[2] https://gitlab.freedesktop.org/xdg/shared-mime-info/-/merge_requests/220
[3] https://github.com/tianocore/tianocore.github.io/wiki/HTTP-Boot#ram-disk-boot-from-http

diff -r ccd7e4022a24 -r a354490ed342 conf/mime.types
--- a/conf/mime.types   Tue Apr 02 20:55:21 2024 +0300
+++ b/conf/mime.types   Wed Apr 03 10:02:15 2024 +0300
@@ -37,6 +37,8 @@
     application/rtf                                  rtf;
     application/vnd.apple.mpegurl                    m3u8;
     application/vnd.debian.binary-package            deb udeb;
+    application/vnd.efi.img                          img;
+    application/vnd.efi.iso                          iso;
     application/vnd.google-earth.kml+xml             kml;
     application/vnd.google-earth.kmz                 kmz;
     application/vnd.ms-excel                         xls;
@@ -75,7 +77,6 @@

     application/octet-stream                         bin exe dll;
     application/octet-stream                         dmg;
-    application/octet-stream                         iso img;
     application/octet-stream                         msi msp msm;

     audio/midi                                       mid midi kar;
# HG changeset patch
# User Yuriy Izorkin <lafiel@elven.pw>
# Date 1712129365 -10800
#      Wed Apr 03 10:29:25 2024 +0300
# Node ID 54edc7ef808a11fd549b8708fcbf6143c3265171
# Parent  a354490ed342b3ae0a6abb8d70db80605294aa97
MIME: update file extensions for audio/ogg type.

For .oga, .ogg, .spx and .opus files, the audio/ogg MIME type
is used according official WIKI page [1] and IANA [2].

The .spx files has traditionally been used for Speex files
within Ogg and should be considered for backwards-compatibility [1].
Link for reference:

In Apache also uses this file extensions [3]:
$ awk '/audio\/ogg/' mime.types
audio/ogg                                       oga ogg spx opus

Link for reference:

[1] https://wiki.xiph.org/MIME_Types_and_File_Extensions
[2] https://www.iana.org/assignments/media-types/audio/ogg
[3] https://svn.apache.org/repos/asf/httpd/httpd/trunk/docs/conf/mime.types

diff -r a354490ed342 -r 54edc7ef808a conf/mime.types
--- a/conf/mime.types   Wed Apr 03 10:02:15 2024 +0300
+++ b/conf/mime.types   Wed Apr 03 10:29:25 2024 +0300
@@ -81,7 +81,7 @@

     audio/midi                                       mid midi kar;
     audio/mpeg                                       mp3;
-    audio/ogg                                        ogg;
+    audio/ogg                                        oga ogg spx opus;
     audio/x-m4a                                      m4a;
     audio/x-realaudio                                ra;

# HG changeset patch
# User Yuriy Izorkin <lafiel@elven.pw>
# Date 1712131093 -10800
#      Wed Apr 03 10:58:13 2024 +0300
# Node ID 91b7825021266a593a23bc3d9528a6acd636e6a1
# Parent  54edc7ef808a11fd549b8708fcbf6143c3265171
MIME: add video/ogg type for ogv files.

For .ogv files, the video/ogg MIME type is used according
official WIKI page [1] and IANA [2].

In Apache also uses this file extensions [3]:
$ awk '/audio\/ogg/' mime.types
video/ogg                                       ogv

Extension usage statistics, according to httparhcive.org [4]:
$ awk 'NR==1||/^ogv,/' httparchive_exts.csv
ext,total_pages,total_requests
ogv,859,2360

Link for reference:

[1] https://wiki.xiph.org/MIME_Types_and_File_Extensions
[2] https://www.iana.org/assignments/media-types/video/ogg
[3] https://svn.apache.org/repos/asf/httpd/httpd/trunk/docs/conf/mime.types
[4] https://httparchive.org

diff -r 54edc7ef808a -r 91b782502126 conf/mime.types
--- a/conf/mime.types   Wed Apr 03 10:29:25 2024 +0300
+++ b/conf/mime.types   Wed Apr 03 10:58:13 2024 +0300
@@ -89,6 +89,7 @@
     video/mp2t                                       ts;
     video/mp4                                        mp4;
     video/mpeg                                       mpeg mpg;
+    video/ogv                                        ogv;
     video/quicktime                                  mov;
     video/webm                                       webm;
     video/x-flv                                      flv;
# HG changeset patch
# User Yuriy Izorkin <lafiel@elven.pw>
# Date 1712132510 -10800
#      Wed Apr 03 11:21:50 2024 +0300
# Node ID c232370384f176077fbc2c4d89702c92a9620923
# Parent  91b7825021266a593a23bc3d9528a6acd636e6a1
MIME: changed type for m4a to audio/mp4.

For files with audio but no visual aspect, the audio/mp4
MIME type is used in accordance with section 2 of RFC 4337 [1].

In Apache also uses this MIME type [2]:
$ awk '/audio\/mp4/' mime.types
audio/mp4                                       m4a mp4a

Link for reference:

[1] https://www.rfc-editor.org/rfc/rfc4337#section-2
[2] https://svn.apache.org/repos/asf/httpd/httpd/trunk/docs/conf/mime.types

diff -r 91b782502126 -r c232370384f1 conf/mime.types
--- a/conf/mime.types   Wed Apr 03 10:58:13 2024 +0300
+++ b/conf/mime.types   Wed Apr 03 11:21:50 2024 +0300
@@ -80,9 +80,9 @@
     application/octet-stream                         msi msp msm;

     audio/midi                                       mid midi kar;
+    audio/mp4                                        m4a;
     audio/mpeg                                       mp3;
     audio/ogg                                        oga ogg spx opus;
-    audio/x-m4a                                      m4a;
     audio/x-realaudio                                ra;

     video/3gpp                                       3gpp 3gp;
# HG changeset patch
# User Yuriy Izorkin <lafiel@elven.pw>
# Date 1712134134 -10800
#      Wed Apr 03 11:48:54 2024 +0300
# Node ID fdf7ff6a59bbd6db9da9874e96f48773ca6e8c2f
# Parent  c232370384f176077fbc2c4d89702c92a9620923
MIME: changed type for m4v to video/mp4.

For files with video, the video/mp4 MIME type is used
in accordance with section 2 of RFC 4337 [1] and IANA [2].

Link for reference:

[1] https://www.rfc-editor.org/rfc/rfc4337#section-2
[2] https://www.iana.org/assignments/media-types/video/mp4

diff -r c232370384f1 -r fdf7ff6a59bb conf/mime.types
--- a/conf/mime.types   Wed Apr 03 11:21:50 2024 +0300
+++ b/conf/mime.types   Wed Apr 03 11:48:54 2024 +0300
@@ -87,13 +87,12 @@

     video/3gpp                                       3gpp 3gp;
     video/mp2t                                       ts;
-    video/mp4                                        mp4;
+    video/mp4                                        mp4 m4v;
     video/mpeg                                       mpeg mpg;
     video/ogv                                        ogv;
     video/quicktime                                  mov;
     video/webm                                       webm;
     video/x-flv                                      flv;
-    video/x-m4v                                      m4v;
     video/x-mng                                      mng;
     video/x-ms-asf                                   asx asf;
     video/x-ms-wmv                                   wmv;
